==> forms-v5.2.1.tar.gz: forms/l10n/is.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Eyðuform",
    "Copy" : "Afrita",
    "Anonymous response" : "Nafnlaust svar",
    "Shared by %s" : "Deilt af %s",
    "responses" : "svör",
    "An error occurred while loading the forms list" : "Villa átti sér stað við að hlaða inn lista yfir eyðuform",
    "Form not found" : "Eyðuform fannst ekki",
    "Unable to create a new form" : "Gat ekki búið til nýtt eyðuform",
    "New form" : "Nýtt eyðuform",
    "Shared with you" : "Deilt með þér",
    "Loading forms …" : "Hleð inn eyðuformum …",
    "No forms created yet" : "Engin eyðuform útbúin ennþá",
    "Create a form" : "Búa til eyðuform",
    "Select a form or create a new one" : "Veldu eyðuform eða búðu til nýtt",
    "Create new form" : "Búa til nýtt eyðuform",
    "This form does not exist" : "Þetta eyðuform er ekki til",
    "Form expired" : "Eyðuform er útrunnið",
    "This form has expired and is no longer taking answers" : "Þetta eyðuform er útrunnið og tekur því ekki lengur við svörum",
    "Select groups" : "Veldu hópa",
    "Delete form" : "Eyða eyðuformi",
    "Error while deleting {title}" : "Villa kom upp við að eyða {title}",
    "Share form" : "Deila eyðuformi",
    "Results" : "Niðurstöður",
    "Are you sure you want to delete {title}?" : "Ertu viss um að þú viljir eyða {title}?",
    "Cancel" : "Hætta við",
    "Options" : "Valkostir",
    "Go to previous page" : "Fara á fyrri síðu",
    "Answer number {index}" : "Svar númer {index}",
    "Error while saving the answer" : "Villa kom upp við að vista svarið",
    "Delete answer" : "Eyða svari",
    "This question needs a title!" : "Þessi spurning þarf að vera með titil!",
    "Question number {index}" : "Spurning númer {index}",
    "Title of question number {index}" : "Titill á spurningu númer {index}",
    "Required" : "þetta þarf",
    "Delete question" : "Eyða spurningu",
    "Maximum file size" : "Hámarks skráastærð",
    "Delete" : "Eyða",
    "Uploading …" : "Sendi inn …",
    "A long answer for the question “{text}”" : "Langt svar við spurningunni “{text}”",
    "Other" : "Annað",
    "A short answer for the question “{text}”" : "Stutt svar við spurningunni “{text}”",
    "No response" : "Ekkert svar",
    "Delete this response" : "Eyða þessu svari",
    "Expired on {date}" : "Rann út {date}",
    "Expires on {date}" : "Rennur út {date}",
    "never" : "aldrei",
    "Set expiration date" : "Setja gildistíma",
    "Group" : "Hópur",
    "Team" : "Teymi",
    "Permissions" : "Heimildir",
    "Share link" : "Deila tengli",
    "Add link" : "Bæta við tengli",
    "Copy to clipboard" : "Afrita á klippispjald",
    "Copy embedding code" : "Afrita ívafningarkóða",
    "Remove link" : "Fjarlægja tengil",
    "Internal link" : "Internal link",
    "View" : "Skoða",
    "Edit" : "Breyta",
    "View mode" : "Skoðunarhamur",
    "Share" : "Deila",
    "Error while saving form" : "Villa við að vista eyðuform",
    "Loading {title} …" : "Hleð inn {title} …",
    "Form title" : "Titill eyðuforms",
    "Description" : "Lýsing",
    "Add a question" : "Bæta við spurningu",
    "Summary" : "Samantekt",
    "Responses" : "Svör",
    "There was an error while removing responses" : "Villa kom upp við að fjarlægja svör",
    "{amount} responses" : "{amount} svör",
    "Download" : "Sækja",
    "Delete all responses" : "Eyða öllum svörum",
    "Search" : "Search",
    "Loading responses …" : "Hleð inn svörum …",
    "Results of submitted forms will show up here" : "Niðurstöður innsendra eyðuforma munu birtast hér",
    "Sharing" : "Deiling",
    "Settings" : "Stillingar",
    "Abort" : "Hætta við",
    "Submit" : "Senda inn",
    "Clear" : "Hreinsa",
    "There was an error submitting the form" : "Það kom upp villa við að senda  eyðuformið inn",
    "Submit form" : "Senda inn eyðuform",
    "Submitting form …" : "Sendi inn eyðuform …",
    "Thank you for completing the form!" : "Takk fyrir að fylla út í eyðuformið!",
    "Error while saving question" : "Villa við að vista spurningu",
    "Form link copied" : "Tengill eyðuforms afritaður",
    "Cannot copy, please copy the link manually" : "Mistókst að afrita, afritaðu tengilinn handvirkt",
    "No recommendations. Start typing." : "Engar tillögur. Byrjaðu að skrifa.",
    "No elements found." : "Engin stök fundust.",
    "Checkboxes" : "Gátreitir",
    "Dropdown" : "Fellilisti",
    "People can pick one option" : "Fólk má velja einn möguleika",
    "Pick an option" : "Veldu einn möguleika",
    "Short answer" : "Stutt svar",
    "Short answer question title" : "Titill spurningar með stutt svar",
    "People can enter a short answer" : "Fólk getur sett inn stutt svar",
    "Long text" : "Langur texti",
    "Long text question title" : "Titill spurningar með langt svar",
    "People can enter a long text" : "Fólk getur sett inn langan texta",
    "Date" : "Dagsetning",
    "Pick a date" : "Veldu dagsetningu",
    "Time" : "Tími",
    "Pick a time" : "Veldu tíma",
    "Color" : "Litur",
    "Image" : "Mynd",
    "Document" : "Skjal",
    "Presentation" : "Kynning",
    "Spreadsheet" : "Töflureiknisskjal",
    "Text" : "Texti",
    "Phone number" : "Símanúmer",
    "Email address" : "Tölvupóstfang"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> forms-v5.2.3.tar.gz: forms/l10n/is.js <==
OC.L10N.register(
    "forms",
    {
    "Forms" : "Eyðuform",
    "Copy" : "Afrita",
    "Anonymous response" : "Nafnlaust svar",
    "Shared by %s" : "Deilt af %s",
    "responses" : "svör",
    "An error occurred while loading the forms list" : "Villa átti sér stað við að hlaða inn lista yfir eyðuform",
    "Form not found" : "Eyðuform fannst ekki",
    "Unable to create a new form" : "Gat ekki búið til nýtt eyðuform",
    "New form" : "Nýtt eyðuform",
    "Shared with you" : "Deilt með þér",
    "No forms created yet" : "Engin eyðuform útbúin ennþá",
    "Create a form" : "Búa til eyðuform",
    "Select a form or create a new one" : "Veldu eyðuform eða búðu til nýtt",
    "Create new form" : "Búa til nýtt eyðuform",
    "This form does not exist" : "Þetta eyðuform er ekki til",
    "Form expired" : "Eyðuform er útrunnið",
    "This form has expired and is no longer taking answers" : "Þetta eyðuform er útrunnið og tekur því ekki lengur við svörum",
    "Select groups" : "Veldu hópa",
    "Delete form" : "Eyða eyðuformi",
    "Error while deleting {title}" : "Villa kom upp við að eyða {title}",
    "Share form" : "Deila eyðuformi",
    "Results" : "Niðurstöður",
    "Are you sure you want to delete {title}?" : "Ertu viss um að þú viljir eyða {title}?",
    "Cancel" : "Hætta við",
    "Options" : "Valkostir",
    "Go to previous page" : "Fara á fyrri síðu",
    "Answer number {index}" : "Svar númer {index}",
    "Error while saving the answer" : "Villa kom upp við að vista svarið",
    "Delete answer" : "Eyða svari",
    "This question needs a title!" : "Þessi spurning þarf að vera með titil!",
    "Question number {index}" : "Spurning númer {index}",
    "Title of question number {index}" : "Titill á spurningu númer {index}",
    "Required" : "þetta þarf",
    "Delete question" : "Eyða spurningu",
    "Maximum file size" : "Hámarks skráastærð",
    "Delete" : "Eyða",
    "A long answer for the question “{text}”" : "Langt svar við spurningunni “{text}”",
    "Other" : "Annað",
    "A short answer for the question “{text}”" : "Stutt svar við spurningunni “{text}”",
    "No response" : "Ekkert svar",
    "Delete this response" : "Eyða þessu svari",
    "Expired on {date}" : "Rann út {date}",
    "Expires on {date}" : "Rennur út {date}",
    "never" : "aldrei",
    "Set expiration date" : "Setja gildistíma",
    "Group" : "Hópur",
    "Team" : "Teymi",
    "Permissions" : "Heimildir",
    "Share link" : "Deila tengli",
    "Add link" : "Bæta við tengli",
    "Copy to clipboard" : "Afrita á klippispjald",
    "Copy embedding code" : "Afrita ívafningarkóða",
    "Remove link" : "Fjarlægja tengil",
    "Internal link" : "Internal link",
    "View" : "Skoða",
    "Edit" : "Breyta",
    "View mode" : "Skoðunarhamur",
    "Share" : "Deila",
    "Error while saving form" : "Villa við að vista eyðuform",
    "Form title" : "Titill eyðuforms",
    "Description" : "Lýsing",
    "Add a question" : "Bæta við spurningu",
    "Summary" : "Samantekt",
    "Responses" : "Svör",
    "There was an error while removing responses" : "Villa kom upp við að fjarlægja svör",
    "{amount} responses" : "{amount} svör",
    "Download" : "Sækja",
    "Delete all responses" : "Eyða öllum svörum",
    "Search" : "Search",
    "Results of submitted forms will show up here" : "Niðurstöður innsendra eyðuforma munu birtast hér",
    "Sharing" : "Deiling",
    "Settings" : "Stillingar",
    "Abort" : "Hætta við",
    "Submit" : "Senda inn",
    "Clear" : "Hreinsa",
    "There was an error submitting the form" : "Það kom upp villa við að senda  eyðuformið inn",
    "Submit form" : "Senda inn eyðuform",
    "Thank you for completing the form!" : "Takk fyrir að fylla út í eyðuformið!",
    "Error while saving question" : "Villa við að vista spurningu",
    "Form link copied" : "Tengill eyðuforms afritaður",
    "Cannot copy, please copy the link manually" : "Mistókst að afrita, afritaðu tengilinn handvirkt",
    "No recommendations. Start typing." : "Engar tillögur. Byrjaðu að skrifa.",
    "No elements found." : "Engin stök fundust.",
    "Checkboxes" : "Gátreitir",
    "Dropdown" : "Fellilisti",
    "People can pick one option" : "Fólk má velja einn möguleika",
    "Pick an option" : "Veldu einn möguleika",
    "Short answer" : "Stutt svar",
    "Short answer question title" : "Titill spurningar með stutt svar",
    "People can enter a short answer" : "Fólk getur sett inn stutt svar",
    "Long text" : "Langur texti",
    "Long text question title" : "Titill spurningar með langt svar",
    "People can enter a long text" : "Fólk getur sett inn langan texta",
    "Date" : "Dagsetning",
    "Pick a date" : "Veldu dagsetningu",
    "Time" : "Tími",
    "Pick a time" : "Veldu tíma",
    "Color" : "Litur",
    "Image" : "Mynd",
    "Document" : "Skjal",
    "Presentation" : "Kynning",
    "Spreadsheet" : "Töflureiknisskjal",
    "Text" : "Texti",
    "Phone number" : "Símanúmer",
    "Email address" : "Tölvupóstfang",
    "Loading forms …" : "Hleð inn eyðuformum …",
    "Uploading …" : "Sendi inn …",
    "Loading {title} …" : "Hleð inn {title} …",
    "Loading responses …" : "Hleð inn svörum …",
    "Submitting form …" : "Sendi inn eyðuform …"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
